@@ -106,8 +106,8 @@ public class CheckEol extends Task {
                     log("Checking file '" + file + "' for correct line ends", Project.MSG_DEBUG);
                     try {
                         check(file, errors, mode);
-                    } catch (IOException ioe) {
-                        throw new BuildException("Could not check file '" + file.getAbsolutePath() + "'", ioe);
+                    } catch (IOException e) {
+                        throw new BuildException("Could not check file '" + file.getAbsolutePath() + "'", e);
                     }
                     count++;
                 }
@@ -131,17 +131,7 @@ public class CheckEol extends Task {
         CRLF
     }
 
-    private static class CheckFailure {
-        private final File file;
-        private final int line;
-        private final String value;
-
-        CheckFailure(File file, int line, String value) {
-            this.file = file;
-            this.line = line;
-            this.value = value;
-        }
-
+    private record CheckFailure(File file, int line, String value) {
         @Override
         public String toString() {
             return System.lineSeparator() + file + ": uses " + value + " on line " + line;
