@@ -65,7 +65,7 @@ public class TestPerMessageDeflate {
      * https://bz.apache.org/bugzilla/show_bug.cgi?id=65317
      */
     @Test
-    public void testMessagePartThatFillsBufffer() throws IOException {
+    public void testMessagePartThatFillsBuffer() throws IOException {
 
         // Set up the extension using defaults
         List<Parameter> parameters = Collections.emptyList();
@@ -87,23 +87,71 @@ public class TestPerMessageDeflate {
 
         MessagePart compressedPart = compressedParts.get(0);
 
-        // Set up the decompression and process the received messafe
+        // Set up the decompression and process the received message
         PerMessageDeflate perMessageDeflateRx = PerMessageDeflate.negotiate(preferences, true);
         perMessageDeflateRx.setNext(new TesterTransformation(compressedPart.getPayload()));
 
         ByteBuffer received = ByteBuffer.allocate(8192);
 
-        TransformationResult tr = perMessageDeflateRx.getMoreData(
-                compressedPart.getOpCode(), compressedPart.isFin(), compressedPart.getRsv(), received);
+        TransformationResult tr = perMessageDeflateRx.getMoreData(compressedPart.getOpCode(), compressedPart.isFin(),
+                compressedPart.getRsv(), received);
 
         Assert.assertEquals(8192, received.position());
-        Assert.assertEquals(TransformationResult.END_OF_FRAME , tr);
+        Assert.assertEquals(TransformationResult.END_OF_FRAME, tr);
     }
 
 
     /*
-     * Minimal implementation to enable other transformations to be tested. It
-     * is NOT robust.
+     * https://bz.apache.org/bugzilla/show_bug.cgi?id=66681
+     */
+    @Test
+    public void testFlushBatchMessagePart() throws IOException {
+        // Set up the extension using defaults
+        List<Parameter> parameters = Collections.emptyList();
+        List<List<Parameter>> preferences = new ArrayList<>();
+        preferences.add(parameters);
+
+        // Set up the compression and sending of the message.
+        PerMessageDeflate perMessageDeflateTx = PerMessageDeflate.negotiate(preferences, true);
+        perMessageDeflateTx.setNext(new TesterTransformation());
+
+        List<MessagePart> uncompressedParts = new ArrayList<>();
+
+        // First message part
+        byte[] data = new byte[1024];
+        ByteBuffer bb = ByteBuffer.wrap(data);
+        MessagePart mp1 = new MessagePart(true, 0, Constants.OPCODE_BINARY, bb, null, null, -1);
+        uncompressedParts.add(mp1);
+
+        // Flush message (replicates result of calling flushBatch()
+        MessagePart mp2 = new MessagePart(true, 0, Constants.INTERNAL_OPCODE_FLUSH, null, null, null, -1);
+        uncompressedParts.add(mp2);
+
+        List<MessagePart> compressedParts = perMessageDeflateTx.sendMessagePart(uncompressedParts);
+
+        Assert.assertEquals(2,  compressedParts.size());
+
+        // Check the first compressed part
+        MessagePart compressedPart1 = compressedParts.get(0);
+
+        // Set up the decompression and process the received message
+        PerMessageDeflate perMessageDeflateRx = PerMessageDeflate.negotiate(preferences, true);
+        perMessageDeflateRx.setNext(new TesterTransformation(compressedPart1.getPayload()));
+
+        ByteBuffer received = ByteBuffer.allocate(8192);
+
+        TransformationResult tr = perMessageDeflateRx.getMoreData(compressedPart1.getOpCode(), compressedPart1.isFin(),
+                compressedPart1.getRsv(), received);
+
+        Assert.assertEquals(1024, received.position());
+        Assert.assertEquals(TransformationResult.END_OF_FRAME, tr);
+
+        // Check the second compressed part (should be passed through unchanged)
+        Assert.assertEquals(mp2, compressedParts.get(1));
+    }
+
+    /*
+     * Minimal implementation to enable other transformations to be tested. It is NOT robust.
      */
     private static class TesterTransformation implements Transformation {
 
@@ -121,30 +169,35 @@ public class TestPerMessageDeflate {
         public boolean validateRsvBits(int i) {
             return false;
         }
+
         @Override
         public boolean validateRsv(int rsv, byte opCode) {
             return false;
         }
+
         @Override
         public void setNext(Transformation t) {
         }
+
         @Override
         public List<MessagePart> sendMessagePart(List<MessagePart> messageParts) {
             return messageParts;
         }
+
         @Override
-        public TransformationResult getMoreData(byte opCode, boolean fin, int rsv, ByteBuffer dest)
-                throws IOException {
+        public TransformationResult getMoreData(byte opCode, boolean fin, int rsv, ByteBuffer dest) throws IOException {
             if (data == null) {
                 return TransformationResult.UNDERFLOW;
             }
             dest.put(data);
             return TransformationResult.END_OF_FRAME;
         }
+
         @Override
         public Extension getExtensionResponse() {
             return null;
         }
+
         @Override
         public void close() {
         }
